@@ -19,5 +19,8 @@ class Factory(Abi):
         ...
 
 
-print(Factory.functions)
-print(Factory.to_abi())
+# print(Factory.functions)
+# print(Factory.to_abi())
+
+
+print(ERC20.Approval.to_abi_item()["inputs"])
